@@ -1,4 +1,7 @@
 from anicli_api import decoders, extractors, re_models
 from anicli_api._http import BaseHTTPAsync, BaseHTTPSync, HTTPAsync, HTTPSync
 from anicli_api.loader import ExtractorLoader
+from anicli_api.logging_config import init_logger
 from anicli_api.tools import RandomAgent
+
+init_logger("anicli-api")
